FixedAmountPayModel class

Inheritance

Constructors

FixedAmountPayModel({required String identifier, required String description, required bool executeInstantly, required PayTypeModel paymentType, String? ccy, double? amount})

Properties

amount ↔ double?
getter/setter pair
ccy ↔ String?
getter/setter pair
description ↔ String
getter/setter pairinherited
executeInstantly ↔ bool
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
identifier → String
finalinherited
paymentType ↔ PayTypeModel
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

callExecute(AppModel app, BuildContext context, String? memberId, AssignmentModel? assignmentModel, bool isNewAssignment, {FinaliseWorkflow? finaliseWorkflow}) → void
inherited
collectReferences({String? appId}) → Future<List<ModelReference>>
override
finishTask(AppModel app, BuildContext context, AssignmentModel assignmentModel, ExecutionResults executionResult, String? feedback) → Future<void>
inherited
getAmount(BuildContext? context) → double?
override
getCcy(BuildContext? context) → String?
override
getOrderNumber(BuildContext context) → String?
override
handleCreditCardPayment(AppModel app, BuildContext theContext, AssignmentModel? theAssignmentModel, PaymentStatus status) → void
inherited
handleManualPayment(AppModel app, BuildContext theContext, AssignmentModel? theAssignmentModel, String paymentReference, String paymentName, bool success) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startTask(AppModel app, BuildContext context, String? memberId, AssignmentModel? assignmentModel) → Future<void>
inherited
toEntity({String? appId}) → TaskEntity
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

definition ↔ String
getter/setter pair
label ↔ String
getter/setter pair

Static Methods

fromEntity(FixedAmountPayEntity entity) → FixedAmountPayModel
override
fromMap(Map snap) → FixedAmountPayEntity